# -*- coding: utf-8 -*-
from django.apps import AppConfig


class WpHoneypotConfig(AppConfig):
    name = 'wp honeypot'
    verbose_name = 'Fancy Title'
    verbose_name_plural = 'Fancy Title'
    label = 'wagtaildocs'
    verbose_name = "Wagtail documents"
